# help

```
usage: help [-h] [-s] [-l]

List available commands

optional arguments:
  -h, --help   show this help message and exit
  -s, --short  Just show the names
  -l, --long   Show the full help text for every command
```
